import uwsgi

import os

def application(env, start_response):

	boundary = 'uwsgi_mjpeg_frame'

	start_response('200 Ok', [

				('Cache-Control', 'no-cache'),
				('Cache-Control', 'private'),
				('Pragma', 'no-cache'),
				('Content-Type', 'multipart/x-mixed-replace; boundary=' + boundary),
				]
			)


	yield "--%s\n" % boundary

	while 1:
		yield "Content-Type: image/jpeg\r\n\r\n"
		uwsgi.sendfile('screenshot.jpg')
		yield "--%s\n" % boundary
		#os.system('./isightcapture -w 640 -h 480 screenshot.jpg')
		#os.system('screencapture -m -T 1 screenshot.jpg')



import os
from distutils import sysconfig

NAME='pyerl'

ERLANGPATH = os.environ.get('UWSGICONFIG_ERLANGPATH', 'erl')

includedir = os.popen(ERLANGPATH + " -noshell -noinput -eval \"io:format('~s~n', [code:lib_dir(erl_interface, include)])\" -s erlang halt").read().rstrip()
libpath = os.popen(ERLANGPATH + " -noshell -noinput -eval \"io:format('~s~n', [code:lib_dir(erl_interface, lib)])\" -s erlang halt").read().rstrip()

CFLAGS = [ '-I' + includedir, '-I' + sysconfig.get_python_inc(), '-I' + sysconfig.get_python_inc(plat_specific=True)]
LDFLAGS = [ '-L' + libpath ]

LIBS = ['-lei']

GCC_LIST = ['pyerl']



import os
NAME='go'

CFLAGS = []
LDFLAGS = []
LIBS = []
GCC_LIST = ['go_plugin']

def post_build(config):
    os.environ['GOPATH'] = 'plugins/go'
    cflags = ['-I'+os.getcwd()] 
    for c in config.cflags:
        if not c.startswith('-DUWSGI_BUILD_DATE') and not c.startswith('-DUWSGI_CFLAGS'):
            cflags.append(c)

    cflags.append('-Wno-implicit-function-declaration')
    cflags.append('-Wno-implicit-int')
    cflags.append('-Wno-unused-function')
    cflags.append('-Wno-unused-variable')
    
    os.environ['CGO_CFLAGS'] = ' '.join(cflags).replace('\\"', '')
    base = os.path.dirname(config.get('bin_name'))
    if not base:
        base = "."
    os.environ['CGO_LDFLAGS'] = '-L' + base + ' -L'+os.getcwd() + ' -luwsgi'
    if os.system("go install uwsgi") != 0:
        os._exit(1)
    print("*** uwsgi go module available in $GOPATH %s/plugins/go ***" % os.getcwd())
